package de.intevation.flys.exports;

import de.intevation.artifactdatabase.state.DefaultSection;
import de.intevation.artifactdatabase.state.DefaultSettings;
import de.intevation.artifactdatabase.state.Section;


/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class ChartSettings extends DefaultSettings {

    protected Section chartSection;
    protected Section axesSection;


    public ChartSettings() {
        super();

        axesSection = new DefaultSection("axes");
        addSection(axesSection);
    }


    /**
     * Sets the chart section. Old chart sections are removed.
     *
     * @param chartSection A new Section that stores chart specific attributes.
     */
    public void setChartSection(Section chartSection) {
        Section oldChartSection = getChartSection();

        if (oldChartSection != null) {
            removeSection(oldChartSection);
        }

        this.chartSection = chartSection;
        addSection(chartSection);
    }


    /**
     * Returns the Section that stores chart specific attributes.
     *
     * @return the Section that stores chart specific attributes.
     */
    public Section getChartSection() {
        return chartSection;
    }


    /**
     * Adds a Section for a new axis of the chart.
     *
     * @param axisSection The Section specific for a chart axis.
     */
    public void addAxisSection(Section axisSection) {
        if (axisSection != null) {
            axesSection.addSubsection(axisSection);
        }
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
